import type { Rule } from 'eslint';

const rule: Rule.RuleModule = {
  meta: {
    type: 'problem',
    docs: {
      description:
        'Ban assignment of empty object literals `{}` and replace them with `Object.create(null)`',
      category: 'Best Practices',
      recommended: true,
    },
    fixable: 'code',
  },
  create: context => ({
    AssignmentExpression(node) {
      if (
        node.operator === '=' &&
        node.right.type === 'ObjectExpression' &&
        node.right.properties.length === 0
      ) {
        context.report({
          node,
          message:
            'Assigning empty object literals are not allowed, use `Object.create(null)` instead.',
          fix: fixer => fixer.replaceText(node.right, 'Object.create(null)'),
        });
      }
    },
  }),
};

export default rule;
